print.rmsEquivTest: Print rmsEquivTest objects
Description
Print rmsEquivTest objects
Usage
# S3 method for rmsEquivTest
print(x, ...)
Value
The function prints a summary of the results of the maximum test based on the bootstrap procedures.
Arguments
- x
An object of class 'rmsEquivTest' containing the results of the maximum test based on the bootstrap procedure.
- ...
Further arguments passed to or from other methods.